@@ -258,11 +258,12 @@ xfce_notify_window_init(XfceNotifyWindow *window)
     gtk_widget_set_name (window->summary, "summary");
     gtk_label_set_max_width_chars (GTK_LABEL(window->summary), screen_width);
     gtk_label_set_ellipsize (GTK_LABEL (window->summary), PANGO_ELLIPSIZE_END);
-    gtk_label_set_line_wrap(GTK_LABEL(window->summary), TRUE);
+    gtk_label_set_line_wrap (GTK_LABEL(window->summary), TRUE);
+    gtk_label_set_line_wrap_mode (GTK_LABEL (window->summary), PANGO_WRAP_WORD_CHAR);
+    gtk_label_set_lines (GTK_LABEL (window->summary), 1);
+    gtk_widget_set_halign (window->summary, GTK_ALIGN_FILL);
 #if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL(window->summary), 0);
-#else
-    gtk_widget_set_halign (window->summary, GTK_ALIGN_START);
 #endif
     gtk_widget_set_valign (window->summary, GTK_ALIGN_BASELINE);
     gtk_box_pack_start(GTK_BOX(vbox), window->summary, TRUE, TRUE, 0);
@@ -271,11 +272,12 @@ xfce_notify_window_init(XfceNotifyWindow *window)
     gtk_widget_set_name (window->body, "body");
     gtk_label_set_max_width_chars (GTK_LABEL(window->body), screen_width);
     gtk_label_set_ellipsize (GTK_LABEL (window->body), PANGO_ELLIPSIZE_END);
-    gtk_label_set_line_wrap(GTK_LABEL(window->body), TRUE);
+    gtk_label_set_line_wrap (GTK_LABEL(window->body), TRUE);
+    gtk_label_set_line_wrap_mode (GTK_LABEL (window->body), PANGO_WRAP_WORD_CHAR);
+    gtk_label_set_lines (GTK_LABEL (window->body), 6);
+    gtk_widget_set_halign (window->body, GTK_ALIGN_FILL);
 #if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL(window->body), 0);
-#else
-    gtk_widget_set_halign (window->body, GTK_ALIGN_START);
 #endif
     gtk_widget_set_valign (window->body, GTK_ALIGN_BASELINE);
     gtk_box_pack_start(GTK_BOX(vbox), window->body, TRUE, TRUE, 0);
@@ -687,29 +689,6 @@ xfce_notify_window_button_clicked(GtkWidget *widget,
                   XFCE_NOTIFY_CLOSE_REASON_DISMISSED);
 }
 
-#define ELEM_B    GUINT_TO_POINTER(1)
-#define ELEM_I    GUINT_TO_POINTER(2)
-#define ELEM_U    GUINT_TO_POINTER(3)
-#define ELEM_A    GUINT_TO_POINTER(4)
-
-static inline const gchar *
-elem_to_string(gconstpointer elem_p)
-{
-    gint elem = GPOINTER_TO_UINT(elem_p);
-    switch(elem) {
-        case GPOINTER_TO_UINT(ELEM_B):
-            return "<b>";
-        case GPOINTER_TO_UINT(ELEM_I):
-            return "<i>";
-        case GPOINTER_TO_UINT(ELEM_U):
-            return "<u>";
-        case GPOINTER_TO_UINT(ELEM_A):
-            return "<a>";
-        default:
-            return "??";
-    }
-}
-
 GtkWidget *
 xfce_notify_window_new(void)
 {
@@ -777,17 +756,18 @@ xfce_notify_window_set_body(XfceNotifyWindow *window,
     g_return_if_fail(XFCE_IS_NOTIFY_WINDOW(window));
 
     if(body && *body) {
-        if (pango_parse_markup (body, -1, 0, NULL, NULL, NULL, NULL)) {
-            gtk_label_set_markup (GTK_LABEL (window->body), body);
-        } else {
+        /* Try to set the body with markup and in case this fails (empty label)
+           fall back to escaping the whole string and showing it plainly.
+           This equals pango_parse_markup extended by checking for valid hyperlinks
+           (which is not supported by pango). */
+        gtk_label_set_markup (GTK_LABEL (window->body), body);
+        if (g_strcmp0 (gtk_label_get_text(GTK_LABEL (window->body)), "") == 0 ) {
             gchar *tmp;
-
             tmp = g_markup_escape_text (body, -1);
             gtk_label_set_text (GTK_LABEL (window->body), body);
             g_free (tmp);
         }
         gtk_widget_show(window->body);
-
         window->has_body_text = TRUE;
     } else {
         gtk_label_set_markup(GTK_LABEL(window->body), "");
