@@ -68,10 +68,6 @@ void xfce_notify_window_set_last_monitor(XfceNotifyWindow *window,
                                          gint monitor);
 gint xfce_notify_window_get_last_monitor(XfceNotifyWindow *window);
 
-void xfce_notify_window_set_last_screen(XfceNotifyWindow *window,
-                                   gint screen);
-gint xfce_notify_window_get_last_screen(XfceNotifyWindow *window);
-
 void xfce_notify_window_set_icon_name(XfceNotifyWindow *window,
                                       const gchar *icon_name);
 void xfce_notify_window_set_icon_pixbuf(XfceNotifyWindow *window,
@@ -101,8 +97,11 @@ void xfce_notify_window_set_gauge_value(XfceNotifyWindow *window,
 void xfce_notify_window_unset_gauge_value(XfceNotifyWindow *window);
 
 void xfce_notify_window_set_do_fadeout(XfceNotifyWindow *window,
-                                       gboolean do_fadeout);
+                                       gboolean do_fadeout,
+                                       gboolean do_slideout);
 
+void xfce_notify_window_set_notify_location(XfceNotifyWindow *window,
+                                            GtkCornerType notify_location);
 /* signal trigger */
 void xfce_notify_window_closed(XfceNotifyWindow *window,
                                XfceNotifyCloseReason reason);
